#ifndef CHROMEOS_CAMERA_CCA_DOCUMENT_SCANNING_DOCUMENT_SCANNER_H_
#define CHROMEOS_CAMERA_CCA_DOCUMENT_SCANNING_DOCUMENT_SCANNER_H_

#include <memory>
#include <vector>

extern "C++" {

namespace photos_intel_actions {
class DocumentCornerDetector;
class DocumentPostProcessor;
} // namespace photos_intel_actions

namespace chromeos_camera {
namespace document_scanning {

class DocumentScanner {
public:
  static std::unique_ptr<DocumentScanner> Create();

  DocumentScanner();
  virtual ~DocumentScanner();

  // Detects the corners of a document.
  virtual bool DetectCorners(const std::vector<uint8_t> &request,
                             std::vector<uint8_t> *result);

  // Do post processing on the given document image based on the given corners.
  virtual bool DoPostProcessing(const std::vector<uint8_t> &request,
                                std::vector<uint8_t> *result);

private:
  std::unique_ptr<photos_intel_actions::DocumentCornerDetector> detector_;
  std::unique_ptr<photos_intel_actions::DocumentPostProcessor> post_processor_;
};

using CreateFn = decltype(&DocumentScanner::Create);

} // namespace document_scanning
} // namespace chromeos_camera

}  // extern "C++"

#endif // CHROMEOS_CAMERA_CCA_DOCUMENT_SCANNING_DOCUMENT_SCANNER_H_
